Three example animal tracks, from Reisinger et al. (2018)
Usage
data(ptt_data)Format
A list containing three tracks collected using Argos PTT tags: DMS from a sooty shearwater, SES from an elephant seal, and AFS from an Antarctic fur seal.
Three example animal tracks, from Reisinger et al. (2018)
data(ptt_data)A list containing three tracks collected using Argos PTT tags: DMS from a sooty shearwater, SES from an elephant seal, and AFS from an Antarctic fur seal.