A land mask based on the full ETOPO1 dataset
Details
Generate a land mask function based on ETOPO1 topography. The etopo geotiff is not bundled with the package and must be downloaded from https://www.ngdc.noaa.gov/mgg/global/global.html.
When the mask is intially created, a native raster (grd, gri)
version of the geotiff is created in the directory tmp,
which must be writable. This file can be deleted when the
computation is finished.
The land argument determines whether the mask function
returns TRUE or FALSE for land. The mask is constant
and the tm argument to the mask is ignored.