Generate a land mask function based on the Global Self-consistent, Hierarchical, High-resolution Geography Database.
The mask is provided at two (approximate) spatial resolutions: 0.1 degree and 0.05 degrees. The latter requires significantly more memory.
The mask is constant and the tm argument to the mask is ignored.
Usage
gshhsMask(res = 0.1, latmin = -90, latmax = 90)
landmask_init(res = 0.1, latmin = -90, latmax = 90)Value
function that returns a logical indicating whether the point is at sea (TRUE) or on land (FALSE)
References
Wessel P, Smith WHF (1996) A Global Self-consistent, Hierarchical, High-resolution Shoreline Database. J. Geophys. Res. 101: 8741-8743. https://www.ngdc.noaa.gov/mgg/shorelines/gshhs.html
Examples
mask <- gshhsMask() ## initialize land mask function
mask(0, c(100, -65)) ## test point lon,lat
#> [1] TRUE