Generate Transition and Covariance Matrices for a simple Crawl Model
Details
Generates the transition and covariance matrices of the state
space model for time increment dt, corresponding to a
fitted crawl model with no drift and no covariates.
Currently no polar adjustment is made.
The matrices are generated assuming the state variables are stored as a vector in the order longitude mu and nu then latitude mu and nu. The parametrization is defined as in the crawl source not the paper, which differs by a factor of \(\beta^{2}\) in the definition of \(\sigma^{2}\).